# ************************************************************************
#  Licensed Material - Property of IBM
# 
#  5724-M24 
# 
#  (c) Copyright IBM Corp. 2007, 2008.  All rights reserved.
# 
#  US Government Users Restricted Rights - Use, duplication or
#  disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
# ************************************************************************

# Created: 07/01/2007


__all__ =  ["outputMode", "outputFormat", "outputWSAdmin"]

from java.lang import System
lineSeparator = System.getProperty("line.separator")


#################################################
#                                               #
# Global variables                              #
#                                               #
#################################################
INDENT = "  "
beginList=[]
outputMode = 1
outputFormat = "text"
outputWSAdmin = "ivt_wsadmin.xml"
MARKER1 = ""
MARKER2 = "- "
MARKER3 = " "
MESG_LEN = 70

#################################################
#                                               #
# Function: sectionBegin  (component,           #
#           testcase, etc)                      #
# Parameters:  name -                           #
#              attr -                           #
#                                               #
#################################################
def sectionBegin(name, attr):
  if (outputMode == 0): 
    return

  if (outputFormat == "xml"):
    attrList = ""
    for key in attr.keys():
      attrList = " " + key + "=\""+attr[key].encoding('utf-8')+"\""
    outputWSAdmin.write(INDENT*(len(beginList)+1) + "<" + name + attrList + ">\r\n") 
  else:  #text
    title = name
    if (attr.has_key('title')):
      title = attr['title']
    print MARKER1 + INDENT*(len(beginList)+1) + MARKER2 + title

  beginList.append(name)
    


#################################################
#                                               #
# Function: sectionEnd  (component, testcase,   #
#           etc)                                #
#                                               #
#################################################
def sectionEnd(printEmptyLine):
  if (outputMode == 0): 
    return
  
  name = beginList.pop()
  if (outputFormat == "xml"):
    outputWSAdmin.write(INDENT*(len(beginList)+1) + "</" + name + ">\r\n")
  else:
    if (printEmptyLine > 0):
      print MARKER1
  

#################################################
#                                               #
# Function: outputResult                        #
# Parameters:  name - item or summary           #
#              mesg -                           #
#              attr - status (pass/fail),       #
#              number of pass/fail,etc          #
#                                               #
#################################################
def outputResult(name,mesg, attr):
  if (outputMode == 0): 
    return

  if (outputFormat == "xml"):
    if (name != "log"):
      attrList = ""
      for key in attr.keys():
        attrList = " " + key + "=\""+attr[key].encoding('utf-8')+"\""
      outputWSAdmin.write(INDENT*(len(beginList)+1) + "<" + name + attrList + ">\r\n") 
      outputWSAdmin.write(INDENT*(len(beginList)+2) + mesg.encoding('utf-8') + "\r\n")  
      outputWSAdmin.write(INDENT*(len(beginList)+1) + "</" + name + ">\r\n") 
  else:
    if (name == "summary" or name == "log"):
      print MARKER1 + INDENT*(len(beginList)+1) + MARKER2 + mesg    
      return

    print MARKER1 + INDENT*(len(beginList)+1) + MARKER2 + mesg + MARKER3 + attr['status']
