# ************************************************************************
#  Licensed Material - Property of IBM
# 
#  5724-M24 
# 
#  Copyright IBM Corp. 2007, 2008.  All rights reserved.
# 
#  US Government Users Restricted Rights - Use, duplication or
#  disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
# ************************************************************************

# Originally from Ke Feng Shao
# Created: 09/21/2006
# Modified: 06/09/2007

"""
 WAS admin actions with need app or dmgr server running
"""

import sys, traceback, StringIO
from java.lang import System
lineSeparator = System.getProperty("line.separator")
from ivtout import outputResult
from com.ibm.wbmonitor.install.common.log import ILogger
from was.CheckResource import CheckResource

from com.ibm.ws.scripting import ScriptingException
from com.ibm.websphere.management.exception import AdminException
from javax.management import MBeanException
from java.sql import SQLException

#__all__ = []

class CheckResourceWithServer(CheckResource):

  className = "CheckResourceWithServer"

  def __init__(self,aa,acf,act,log, resolver):
    self.AdminControl   = act
    CheckResource.__init__(self,aa, acf, log, resolver)

    



#########################################################
#                                                       #
# Function: Verfiy DataSource Connnection               #
# Parameters:                                           #
#   resource  - type of resource, like 'DataSource'     #
#   attribute - attribute of 'resource' which will be   #
#               verified, like 'name'                   #
#   expectedList - 'attribute' values of expected       #
#                  'resource' list                      #
#                                                       #
#########################################################
  def testConnection(self,resource,attribute,expectedList):
    
    methodName = "testConnection"
    errorCount = 0
    resList = self.AdminConfig.list(resource)
    if (len(resList) == 0): 
      mesg = resource + " is not installed"
      outputResult("item", resource, {'status':self.failed})
      self.logger.msg(ILogger.TYPE_WARN, CheckResourceWithServer.className, 
		      methodName, mesg) 
      errorCount += 1
      return errorCount

    resArray =  resList.split(lineSeparator)
    resNameArray = []

    for res in resArray:
      resName = self.AdminConfig.showAttribute(res,attribute) 
      resNameArray.append(resName) 

    for res in expectedList:
      if (res in resNameArray):
        try:
          dsid = self.AdminConfig.getid("/DataSource:" + res + "/")
          tcResult = self.AdminControl.testConnection(dsid)
          if (tcResult.find("Connection to provided datasource was successful")):
            mesg = res + " tests connection successful"
            outputResult("item", res, {'status':self.passed})
	    self.logger.msg(ILogger.TYPE_INFO, CheckResourceWithServer.className, 
			    methodName, mesg) 
          else:
            mesg = res + " tests connection failed"
            outputResult("item", res, {'status':self.failed})
	    self.logger.msg(ILogger.TYPE_WARN, CheckResourceWithServer.className, 
			    methodName, mesg) 
            errorCount += 1
	#except ScriptingException, e:
	except AdminException, e:
          mesg = res + " tests connection gets exception"
	  self.logger.msg(ILogger.TYPE_ERROR, CheckResourceWithServer.className, 
			  methodName, mesg) 
	  self.logger.msg(ILogger.TYPE_ERROR, CheckResourceWithServer.className, 
           	          methodName, e.getMessage())
          outputResult("item", res, {'status':self.failed})
          errorCount += 1
	#except MBeanException, e:
	#except SQLException, e: #thisi what I want but can't get except
	#let system print whole exception trace (don't catch)
	except: 
	  #traceback.print_exc()
          mesg = res + " tests connection gets exception"
	  self.logger.msg(ILogger.TYPE_WARN, CheckResourceWithServer.className, 
			  methodName, mesg) 
	  #etype, value, tb = sys.exc_info()

          sp = StringIO.StringIO()
	  traceback.print_exc(file=sp)

          mesg = sp.getvalue()
	  self.logger.msg(ILogger.TYPE_ERROR, CheckResourceWithServer.className, 
           	          methodName, mesg )
	  #print mesg
          #print traceback.format_exception(etype,value,tb)
          outputResult("item", res, {'status':self.failed})
          errorCount += 1
      else:
        mesg = res +  " is not installed"
        outputResult("item", res, {'status':self.failed})
	self.logger.msg(ILogger.TYPE_WARN, CheckResourceWithServer.className, 
			methodName, mesg) 
        errorCount += 1

    return errorCount


#########################################################
#                                                       #
# Function: Verfiy whether specified applications are   #
#           installed                                   #
# Parameters:                                           # 
#   expectedList - application names expected to install#
#                                                       #
#########################################################
  def checkApplicationsStatus(self,expectedList):
    methodName = "checkApplicationStatus"
    errorCount = 0
    appList = self.AdminApp.list()
    appArray =  appList.split(lineSeparator)

    for app in expectedList:
      isExist = 0
      for appTemp in appArray:	
        if (appTemp.startswith(app)):
  	  isExist = 1
	  break
      if (isExist):
        status = self.AdminControl.completeObjectName('type=Application,name='+appTemp+',*')
        if (status == ""):
          mesg = app + " is installed but not started"
          outputResult("item", app, {'status':self.failed})
	  self.logger.msg(ILogger.TYPE_WARN, CheckResourceWithServer.className, 
	                  methodName, mesg) 
          errorCount += 1
        else:
          mesg = app + " is running"
	  self.logger.msg(ILogger.TYPE_INFO, CheckResourceWithServer.className, 
	                  methodName, mesg) 
          outputResult("item", app, {'status':self.passed})
      else:
        mesg = app + " isn't installed"
        outputResult("item", app, {'status':self.failed})
        self.logger.msg(ILogger.TYPE_WARN, CheckResourceWithServer.className, 
	                  methodName, mesg) 
        errorCount += 1
    return errorCount
