@rem Licensed Materials - Property of IBM
@rem 5724-M24
@rem Copyright IBM Corporation 2008, 2009. All Rights Reserved.
@rem US Government Users Restricted Rights- Use, duplication or disclosure
@rem restricted by GSA ADP Schedule Contract with IBM Corp.
@rem **************************************************************************
@rem Upgrade the Monitor configurations: 
@rem   - Upgrade all Alphablox cubes (6.1 only)
@rem   - Register all migrated models to Data Service Scheduler (6.1 only)
@rem **************************************************************************

@echo off
setlocal

@rem set WAS home
set CUR_DIR=%cd%
cd /d "%~dp0\..\..\.."
set WAS_HOME=%cd%
cd /d "%CUR_DIR%"

set WSADMIN_HOST=localhost
set WSADMIN_PORT=8880
set WSADMIN_CONN_TYPE=SOAP
set WSADMIN_USER=user
set WSADMIN_PASSWORD=password
set WSADMIN_CLASSPATH=%WAS_HOME%\plugins\com.ibm.wbimonitor.lifecycle.spi.jar

set ABX_HOST=.
set ABX_PORT=.
set ABX_USER=.
set ABX_PASSWORD=.

set LOG_DIR=%WAS_HOME%\logs\wbm\migration
if not exist "%LOG_DIR%" mkdir "%LOG_DIR%"
set LOG_FILE=%LOG_DIR%\monitor_configuration_upgrade_log.txt

echo **************************************************************************
echo Upgrade the Monitor configurations from 6.x to 7.0
echo **************************************************************************
echo Please check the required wsadmin parameters defined in monConfigurationUpgrade.bat, 
echo and they are used to connect to the Monitor server.
echo    ^<WSADMIN_HOST^>      = %WSADMIN_HOST%
echo    ^<WSADMIN_PORT^>      = %WSADMIN_PORT%
echo    ^<WSADMIN_CONN_TYPE^> = %WSADMIN_CONN_TYPE%
echo    ^<WSADMIN_USER^>      = %WSADMIN_USER%
echo    ^<WSADMIN_PASSWORD^>  = %WSADMIN_PASSWORD%
echo.

echo Please also check the optional Alphablox server configuration, 
echo and the cubes on the default or specified Alphablox server will be upgraded.
echo    ^<ABX_HOST^>      = %ABX_HOST%
echo    ^<ABX_PORT^>      = %ABX_PORT%
echo    ^<ABX_USER^>      = %ABX_USER%
echo    ^<ABX_PASSWORD^>  = %ABX_PASSWORD%
echo.
echo    Usage 1: upgrade the cubes in the default Alphablox server which was specified in the Monitor database
echo       ^<ABX_HOST^>      = .
echo       ^<ABX_PORT^>      = .
echo       ^<ABX_USER^>      = .
echo       ^<ABX_PASSWORD^>  = .
echo    Usage 2: upgrade the cubes in the specified Alphablox server with security disabled
echo       ^<ABX_HOST^>      = hostname or IP (e.g. localhost)
echo       ^<ABX_PORT^>      = BOOTSTRAP_ADDRESS (e.g. 2809)
echo       ^<ABX_USER^>      = .
echo       ^<ABX_PASSWORD^>  = .
echo    Usage 3: upgrade the cubes in the specified Alphablox server with security enabled
echo       ^<ABX_HOST^>      = hostname or IP (e.g. localhost)
echo       ^<ABX_PORT^>      = BOOTSTRAP_ADDRESS (e.g. 2809)
echo       ^<ABX_USER^>      = user
echo       ^<ABX_PASSWORD^>  = password
echo.

set /p para=Continue? [Input Y to continue or input N if you want to modify the listed parameters]:
set para=%para%o
if %para% == No (
	echo Exit the program, and please edit the parameters in monConfigurationUpgrade.bat
	goto exit
)
if %para% == no (
	echo Exit the program, and please edit the parameters in monConfigurationUpgrade.bat
	goto exit
)

:version
echo.
set /p VERSION=Please input the version of the old Monitor[61 or 62]:
if not %VERSION%==61 (
if not %VERSION%==62 (
	echo The version %version% is not supported , and please input 61 or 62.
	goto version
))

echo.
echo Start to upgrade the Monitor configurations, and after it's completed, you could check the log file: %LOG_FILE%.

@rem **************************************************************************
@rem Upgrade the Alphablox cubes in the default Alphablox server 
@rem which was configured for each model version in the Monitor database
@rem **************************************************************************
if %ABX_HOST% == . (
if %ABX_PORT% == . (
	"%WAS_HOME%\bin\wsadmin" -lang jython -conntype %WSADMIN_CONN_TYPE% -host %WSADMIN_HOST% -port %WSADMIN_PORT% -user %WSADMIN_USER% -password %WSADMIN_PASSWORD% -wsadmin_classpath "%WSADMIN_CLASSPATH%" -f monConfigurationUpgrade.jy %VERSION% > "%LOG_FILE%" 2>&1
	goto exit
))


@rem **************************************************************************
@rem Upgrade the Alphablox cubes in the specified Alphablox server 
@rem which security	is disabled
@rem **************************************************************************
if not %ABX_HOST% == . (
if not %ABX_PORT% == . (
if %ABX_USER% == . (
if %ABX_PASSWORD% == . (
	"%WAS_HOME%\bin\wsadmin" -lang jython -conntype %WSADMIN_CONN_TYPE% -host %WSADMIN_HOST% -port %WSADMIN_PORT% -user %WSADMIN_USER% -password %WSADMIN_PASSWORD% -wsadmin_classpath "%WSADMIN_CLASSPATH%" -f monConfigurationUpgrade.jy %VERSION% %ABX_HOST% %ABX_PORT% > "%LOG_FILE%" 2>&1
	goto exit
))))


@rem **************************************************************************
@rem Upgrade the Alphablox cubes in the specified Alphablox server 
@rem which security	is enabled
@rem **************************************************************************
if not %ABX_HOST% == . (
if not %ABX_PORT% == . (
if not %ABX_USER% == . (
if not %ABX_PASSWORD% == . (
	"%WAS_HOME%\bin\wsadmin" -lang jython -conntype %WSADMIN_CONN_TYPE% -host %WSADMIN_HOST% -port %WSADMIN_PORT% -user %WSADMIN_USER% -password %WSADMIN_PASSWORD% -wsadmin_classpath "%WSADMIN_CLASSPATH%" -f monConfigurationUpgrade.jy %VERSION% %ABX_HOST% %ABX_PORT% %ABX_USER% %ABX_PASSWORD% > "%LOG_FILE%" 2>&1
	goto exit
))))

echo Invalid Alphablox server configuration, and please edit them in monConfigurationUpgrade.bat

:exit

endlocal
@echo on